<?php

namespace Notifications\Notification\Providers;

use Illuminate\Support\ServiceProvider;

class NotificationServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'notification');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'notification');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('notifications.notification', function ($app) {
            return $this->app->make('Notifications\Notification\Notification');
        });

                // Bind Notifications to repository
        $this->app->bind(
            'Notifications\Notification\Interfaces\NotificationsRepositoryInterface',
            \Notifications\Notification\Repositories\Eloquent\NotificationsRepository::class
        );

        $this->app->register(\Notifications\Notification\Providers\AuthServiceProvider::class);
                $this->app->register(\Notifications\Notification\Providers\EventServiceProvider::class);
        
        $this->app->register(\Notifications\Notification\Providers\RouteServiceProvider::class);
                $this->app->register(\Notifications\Notification\Providers\WorkflowServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['notifications.notification'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('notifications/notification.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/notification')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/notification')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
